@@ -2,13 +2,13 @@ package Faker::Role;
 
 use Extorter;
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 sub import {
     my $class  = shift;
     my $target = caller;
 
-    $class->extort::into($target, '*Moo::Role');
+    $class->extort::into($target, '*Data::Object::Role');
     $class->extort::into($target, '*Faker::Signature');
     $class->extort::into($target, '*Faker::Type');
 
